about summary refs log tree commit diff
path: root/debug
diff options
context:
space:
mode:
Diffstat (limited to 'debug')
-rw-r--r--debug/wctomb_chk.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/debug/wctomb_chk.c b/debug/wctomb_chk.c
index d0366346b8..23fc2ffbd1 100644
--- a/debug/wctomb_chk.c
+++ b/debug/wctomb_chk.c
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 Free Software Foundation, Inc.
+/* Copyright (C) 2005, 2008 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@
 #include <wcsmbs/wcsmbsload.h>
 
 
-extern mbstate_t __no_r_state attribute_hidden;	/* Defined in mbtowc.c.  */
+extern mbstate_t __wctomb_state attribute_hidden; /* Defined in wctomb.c.  */
 
 
 int
@@ -32,5 +32,5 @@ __wctomb_chk (char *s, wchar_t wchar, size_t buflen)
   if (buflen < MB_CUR_MAX)
     __chk_fail ();
 
-  return __wcrtomb (s, wchar, &__no_r_state);
+  return __wcrtomb (s, wchar, &__wctomb_state);
 }